/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.3.0 (build: 2013-04-09 19:13:20 UTC)
 *  on 2013-04-10 at 02:16:02 UTC 
 */

package com.google.api.services.latitude;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Latitude (v1).
 *
 * <p>
 * Lets you read and update your current location and work with your location history
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/latitude/v1/using" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link LatitudeRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Latitude extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Google Latitude API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "latitude/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Latitude(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        true);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Latitude(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the CurrentLocation collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Latitude latitude = new Latitude(...);}
   *   {@code Latitude.CurrentLocation.List request = latitude.currentLocation().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public CurrentLocation currentLocation() {
    return new CurrentLocation();
  }

  /**
   * The "currentLocation" collection of methods.
   */
  public class CurrentLocation {

    /**
     * Deletes the authenticated user's current location.
     *
     * Create a request for the method "currentLocation.delete".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public Delete delete() throws java.io.IOException {
      Delete result = new Delete();
      initialize(result);
      return result;
    }

    public class Delete extends LatitudeRequest<Void> {

      private static final String REST_PATH = "currentLocation";

      /**
       * Deletes the authenticated user's current location.
       *
       * Create a request for the method "currentLocation.delete".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected Delete() {
        super(Latitude.this, "DELETE", REST_PATH, null, Void.class);
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

    }
    /**
     * Returns the authenticated user's current location.
     *
     * Create a request for the method "currentLocation.get".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public Get get() throws java.io.IOException {
      Get result = new Get();
      initialize(result);
      return result;
    }

    public class Get extends LatitudeRequest<com.google.api.services.latitude.model.Location> {

      private static final String REST_PATH = "currentLocation";

      /**
       * Returns the authenticated user's current location.
       *
       * Create a request for the method "currentLocation.get".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected Get() {
        super(Latitude.this, "GET", REST_PATH, null, com.google.api.services.latitude.model.Location.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Granularity of the requested location. */
      @com.google.api.client.util.Key
      private String granularity;

      /** Granularity of the requested location. [default: city]
       */
      public String getGranularity() {
        return granularity;
      }

      /** Granularity of the requested location. */
      public Get setGranularity(String granularity) {
        this.granularity = granularity;
        return this;
      }

    }
    /**
     * Updates or creates the user's current location.
     *
     * Create a request for the method "currentLocation.insert".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.latitude.model.Location}
     * @return the request
     */
    public Insert insert(com.google.api.services.latitude.model.Location content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends LatitudeRequest<com.google.api.services.latitude.model.Location> {

      private static final String REST_PATH = "currentLocation";

      /**
       * Updates or creates the user's current location.
       *
       * Create a request for the method "currentLocation.insert".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.latitude.model.Location}
       * @since 1.13
       */
      protected Insert(com.google.api.services.latitude.model.Location content) {
        super(Latitude.this, "POST", REST_PATH, content, com.google.api.services.latitude.model.Location.class);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

    }

  }

  /**
   * An accessor for creating requests from the Location collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Latitude latitude = new Latitude(...);}
   *   {@code Latitude.Location.List request = latitude.location().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Location location() {
    return new Location();
  }

  /**
   * The "location" collection of methods.
   */
  public class Location {

    /**
     * Deletes a location from the user's location history.
     *
     * Create a request for the method "location.delete".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param locationId Timestamp of the location to delete (ms since epoch).
     * @return the request
     */
    public Delete delete(String locationId) throws java.io.IOException {
      Delete result = new Delete(locationId);
      initialize(result);
      return result;
    }

    public class Delete extends LatitudeRequest<Void> {

      private static final String REST_PATH = "location/{locationId}";

      /**
       * Deletes a location from the user's location history.
       *
       * Create a request for the method "location.delete".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param locationId Timestamp of the location to delete (ms since epoch).
       * @since 1.13
       */
      protected Delete(String locationId) {
        super(Latitude.this, "DELETE", REST_PATH, null, Void.class);
        this.locationId = Preconditions.checkNotNull(locationId, "Required parameter locationId must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Timestamp of the location to delete (ms since epoch). */
      @com.google.api.client.util.Key
      private String locationId;

      /** Timestamp of the location to delete (ms since epoch).
       */
      public String getLocationId() {
        return locationId;
      }

      /** Timestamp of the location to delete (ms since epoch). */
      public Delete setLocationId(String locationId) {
        this.locationId = locationId;
        return this;
      }

    }
    /**
     * Reads a location from the user's location history.
     *
     * Create a request for the method "location.get".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param locationId Timestamp of the location to read (ms since epoch).
     * @return the request
     */
    public Get get(String locationId) throws java.io.IOException {
      Get result = new Get(locationId);
      initialize(result);
      return result;
    }

    public class Get extends LatitudeRequest<com.google.api.services.latitude.model.Location> {

      private static final String REST_PATH = "location/{locationId}";

      /**
       * Reads a location from the user's location history.
       *
       * Create a request for the method "location.get".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param locationId Timestamp of the location to read (ms since epoch).
       * @since 1.13
       */
      protected Get(String locationId) {
        super(Latitude.this, "GET", REST_PATH, null, com.google.api.services.latitude.model.Location.class);
        this.locationId = Preconditions.checkNotNull(locationId, "Required parameter locationId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Timestamp of the location to read (ms since epoch). */
      @com.google.api.client.util.Key
      private String locationId;

      /** Timestamp of the location to read (ms since epoch).
       */
      public String getLocationId() {
        return locationId;
      }

      /** Timestamp of the location to read (ms since epoch). */
      public Get setLocationId(String locationId) {
        this.locationId = locationId;
        return this;
      }

      /** Granularity of the location to return. */
      @com.google.api.client.util.Key
      private String granularity;

      /** Granularity of the location to return. [default: city]
       */
      public String getGranularity() {
        return granularity;
      }

      /** Granularity of the location to return. */
      public Get setGranularity(String granularity) {
        this.granularity = granularity;
        return this;
      }

    }
    /**
     * Inserts or updates a location in the user's location history.
     *
     * Create a request for the method "location.insert".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.latitude.model.Location}
     * @return the request
     */
    public Insert insert(com.google.api.services.latitude.model.Location content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends LatitudeRequest<com.google.api.services.latitude.model.Location> {

      private static final String REST_PATH = "location";

      /**
       * Inserts or updates a location in the user's location history.
       *
       * Create a request for the method "location.insert".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.latitude.model.Location}
       * @since 1.13
       */
      protected Insert(com.google.api.services.latitude.model.Location content) {
        super(Latitude.this, "POST", REST_PATH, content, com.google.api.services.latitude.model.Location.class);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

    }
    /**
     * Lists the user's location history.
     *
     * Create a request for the method "location.list".
     *
     * This request holds the parameters needed by the the latitude server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends LatitudeRequest<com.google.api.services.latitude.model.LocationFeed> {

      private static final String REST_PATH = "location";

      /**
       * Lists the user's location history.
       *
       * Create a request for the method "location.list".
       *
       * This request holds the parameters needed by the the latitude server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Latitude.this, "GET", REST_PATH, null, com.google.api.services.latitude.model.LocationFeed.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Maximum number of locations to return. */
      @com.google.api.client.util.Key("max-results")
      private String maxResults;

      /** Maximum number of locations to return.
       */
      public String getMaxResults() {
        return maxResults;
      }

      /** Maximum number of locations to return. */
      public List setMaxResults(String maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Maximum timestamp of locations to return (ms since epoch). */
      @com.google.api.client.util.Key("max-time")
      private String maxTime;

      /** Maximum timestamp of locations to return (ms since epoch).
       */
      public String getMaxTime() {
        return maxTime;
      }

      /** Maximum timestamp of locations to return (ms since epoch). */
      public List setMaxTime(String maxTime) {
        this.maxTime = maxTime;
        return this;
      }

      /** Minimum timestamp of locations to return (ms since epoch). */
      @com.google.api.client.util.Key("min-time")
      private String minTime;

      /** Minimum timestamp of locations to return (ms since epoch).
       */
      public String getMinTime() {
        return minTime;
      }

      /** Minimum timestamp of locations to return (ms since epoch). */
      public List setMinTime(String minTime) {
        this.minTime = minTime;
        return this;
      }

      /** Granularity of the requested locations. */
      @com.google.api.client.util.Key
      private String granularity;

      /** Granularity of the requested locations. [default: city]
       */
      public String getGranularity() {
        return granularity;
      }

      /** Granularity of the requested locations. */
      public List setGranularity(String granularity) {
        this.granularity = granularity;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Latitude}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          true);
    }

    /** Builds a new instance of {@link Latitude}. */
    @Override
    public Latitude build() {
      return new Latitude(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link LatitudeRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setLatitudeRequestInitializer(
        LatitudeRequestInitializer latitudeRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(latitudeRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
